summaryrefslogtreecommitdiffstats
path: root/generic/tclFCmd.c
diff options
context:
space:
mode:
authorredman <redman>1999-07-01 23:21:06 (GMT)
committerredman <redman>1999-07-01 23:21:06 (GMT)
commit733df6bdb27c26175f854cf69d08f0cfef9e855e (patch)
treea91f8b07763f9757ab1d5d9718aaefa36e855881 /generic/tclFCmd.c
parentcbc160d0d87b1efa3096c590343d0553633cb9cc (diff)
downloadtcl-733df6bdb27c26175f854cf69d08f0cfef9e855e.zip
tcl-733df6bdb27c26175f854cf69d08f0cfef9e855e.tar.gz
tcl-733df6bdb27c26175f854cf69d08f0cfef9e855e.tar.bz2
Call TclStat instead of TclpStat in order to allow the
stat hooks to work properly.
Diffstat (limited to 'generic/tclFCmd.c')
-rw-r--r--generic/tclFCmd.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/generic/tclFCmd.c b/generic/tclFCmd.c
index 32c7186..d975cc6 100644
--- a/generic/tclFCmd.c
+++ b/generic/tclFCmd.c
@@ -9,7 +9,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclFCmd.c,v 1.5 1999/04/21 21:50:25 rjohnson Exp $
+ * RCS: @(#) $Id: tclFCmd.c,v 1.6 1999/07/01 23:21:07 redman Exp $
*/
#include "tclInt.h"
@@ -141,12 +141,12 @@ FileCopyRename(interp, argc, argv, copyFlag)
result = TCL_OK;
/*
* Call TclpStat() so that if target is a symlink that points to a
* directory we will put the sources in that directory instead of
* overwriting the symlink.
*/
- if ((TclpStat(target, &statBuf) != 0) || !S_ISDIR(statBuf.st_mode)) {
+ if ((TclStat(target, &statBuf) != 0) || !S_ISDIR(statBuf.st_mode)) {
if ((argc - i) > 2) {
errno = ENOTDIR;
Tcl_PosixError(interp);
@@ -253,12 +253,12 @@ TclFileMakeDirsCmd(interp, argc, argv)
char *target = Tcl_JoinPath(j + 1, pargv, &targetBuffer);
/*
* Call TclpStat() so that if target is a symlink that points
* to a directory we will create subdirectories in that
* directory.
*/
- if (TclpStat(target, &statBuf) == 0) {
+ if (TclStat(target, &statBuf) == 0) {
if (!S_ISDIR(statBuf.st_mode)) {
errno = EEXIST;
errfile = target;
@@ -141,12 +141,12 @@ FileCopyRename(interp, argc, argv, copyFlag)
result = TCL_OK;
/*
- * Call TclpStat() so that if target is a symlink that points to a
+ * Call TclStat() so that if target is a symlink that points to a
* directory we will put the sources in that directory instead of
* overwriting the symlink.
@@ -253,12 +253,12 @@ TclFileMakeDirsCmd(interp, argc, argv)
char *target = Tcl_JoinPath(j + 1, pargv, &targetBuffer);
/*
- * Call TclpStat() so that if target is a symlink that points
+ * Call TclStat() so that if target is a symlink that points
* to a directory we will create subdirectories in that
* directory.